@@ -4,6 +4,7 @@ import time
 import errno
 import shutil
 import pytest
+from cStringIO import StringIO
 import logging
 ## utility for tests that configures logging in roughly the same way
 ## that a program calling bigtree should setup logging
@@ -20,6 +21,7 @@ from . import make_stream_item, ContentItem, Chunk, serialize, deserialize, comp
 from . import VersionMismatchError
 from . import Versions
 from . import StreamItem_v0_2_0, StreamItem_v0_3_0
+from streamcorpus import _chunk
 
 TEST_XZ_PATH = os.path.join(os.path.dirname(__file__), '../../../test-data/john-smith-tagged-by-lingpipe-0-v0_2_0.sc.xz')
 TEST_SC_PATH = os.path.join(os.path.dirname(__file__), '../../../test-data/john-smith-tagged-by-lingpipe-0-v0_2_0.sc')
@@ -49,6 +51,23 @@ def test_chunk():
     ch.add( si )
     assert len(ch) == 1
 
+def test_chunk_wrapper():
+    ## write in-memory
+    fh = StringIO()
+    ch = Chunk(file_obj=fh, write_wrapper=lambda x: x['dog'], mode='wb')
+    assert ch.mode == 'wb'
+    si = make_si()
+    si = dict(dog=si)
+    ch.add( si )
+    assert len(ch) == 1
+    ch.flush()
+    blob = fh.getvalue()
+    assert blob
+    fh = StringIO(blob)
+    ch = Chunk(file_obj=fh, read_wrapper=lambda x: dict(dog=x), mode='rb')
+    si2 = list(ch)[0]
+    assert si2 == si
+
 def test_xz():
     count = 0
     for si in Chunk(TEST_XZ_PATH, message=StreamItem_v0_2_0):
@@ -68,6 +87,17 @@ def test_gz():
     assert count == 197
     os.system('rm %s' % test_gz_path)
 
+@pytest.mark.skipif('not _chunk.lzma')
+def test_xz_write():
+    count = 0
+    test_xz_path = '/tmp/test_path.xz'
+    ## hinted by ".xz"
+    o_chunk = Chunk(test_xz_path, mode='wb')
+    o_chunk.add(make_si())
+    o_chunk.close()
+    assert len(list(Chunk(test_xz_path))) == 1
+    os.system('rm %s' % test_xz_path)
+
 def test_speed():
     count = 0
     start_time = time.time()
@@ -88,6 +118,14 @@ def path(request):
     request.addfinalizer(fin)
     return path
 
+@pytest.fixture(scope='function')
+def path_xz(request):
+    path = '/tmp/test_chunk-%s.sc.xz' % str(uuid.uuid4())
+    def fin():
+        os.remove(path)
+    request.addfinalizer(fin)
+    return path
+
 def test_chunk_path_write(path):
     ## write to path
     ch = Chunk(path=path, mode='wb')
@@ -114,6 +152,23 @@ def test_chunk_path_append(path):
     print repr(ch)
     assert len(list( Chunk(path=path, mode='rb') )) == 2
 
+@pytest.mark.skipif('not _chunk.lzma')
+def test_chunk_path_append_xz(path_xz):
+    ch = Chunk(path=path_xz, mode='wb')
+    si = make_si()
+    ch.add( si )
+    ch.close()
+    assert len(ch) == 1
+    ## append to path
+    ch = Chunk(path=path_xz, mode='ab')
+    si = make_si()
+    ch.add( si )
+    ch.close()
+    ## count is only for those added
+    assert len(ch) == 1
+    print repr(ch)
+    assert len(list( Chunk(path=path_xz, mode='rb') )) == 2
+
 def test_chunk_path_read_1(path):
     ch = Chunk(path=path, mode='wb')
     ch.add( make_si() )
